package digital.laboratory.platform.entrustment.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.date.LocalDateTimeUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.beust.ah.A;
import digital.laboratory.platform.common.core.exception.CheckedException;
import digital.laboratory.platform.common.core.util.R;
import digital.laboratory.platform.entrustment.convert.DrugLiteConvert;
import digital.laboratory.platform.entrustment.convert.EntrustMaterialCheckoutResultConvert;
import digital.laboratory.platform.entrustment.dto.CheckoutResultExcelDTO;
import digital.laboratory.platform.entrustment.dto.EntrustMaterialCheckoutResultDTO;
import digital.laboratory.platform.entrustment.dto.ResultExcelDTO;
import digital.laboratory.platform.entrustment.entity.EntrustMaterialCheckoutResult;
import digital.laboratory.platform.entrustment.entity.Entrustment;
import digital.laboratory.platform.entrustment.entity.EntrustmentIdentificationMaterial;
import digital.laboratory.platform.entrustment.enums.EntrustStatusConstants;
import digital.laboratory.platform.entrustment.mapper.EntrustMaterialCheckoutResultMapper;
import digital.laboratory.platform.entrustment.mapper.EntrustmentIdentificationMaterialMapper;
import digital.laboratory.platform.entrustment.query.EntrustMaterialCheckoutResultQuery;
import digital.laboratory.platform.entrustment.service.CommonFeignService;
import digital.laboratory.platform.entrustment.service.EntrustMaterialCheckoutResultService;
import digital.laboratory.platform.entrustment.service.EntrustmentIdentificationMaterialService;
import digital.laboratory.platform.entrustment.service.EntrustmentService;
import digital.laboratory.platform.entrustment.vo.DetectionRateVO;
import digital.laboratory.platform.entrustment.vo.EntrustMaterialCheckoutResultVO;
import digital.laboratory.platform.entrustment.vo.EntrustmentIdentificationMaterialVO;
import digital.laboratory.platform.sys.entity.Area;
import digital.laboratory.platform.sys.entity.DrugLite;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.net.URLEncoder;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.*;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * @author ChenJiangBao
 * @description 针对表【b_entrust_material_checkout_result(委托检材--检出定性定量结果信息)】的数据库操作Service实现
 * @createDate 2024-12-30 16:16:25
 */
@Service
public class EntrustMaterialCheckoutResultServiceImpl extends ServiceImpl<EntrustMaterialCheckoutResultMapper, EntrustMaterialCheckoutResult>
        implements EntrustMaterialCheckoutResultService {

    @Resource
    private EntrustmentService entrustmentService;

    @Resource
    private EntrustmentIdentificationMaterialService entrustmentIdentificationMaterialService;

    @Resource
    private CommonFeignService commonFeignService;

    @Resource
    private EntrustmentIdentificationMaterialMapper entrustmentIdentificationMaterialMapper;

    /**
     * 构建委托材料检验结果字符串
     *
     * @param entrustId 委托ID
     * @return 委托材料检验结果字符串
     */
    @Override
    public String buildEntrustMaterialCheckoutResultStr(String entrustId) {
        // 先获取检材列表
//        List<EntrustmentIdentificationMaterial> materialList = entrustmentIdentificationMaterialService.list(Wrappers.<EntrustmentIdentificationMaterial>lambdaQuery().eq(EntrustmentIdentificationMaterial::getEntrustmentId, entrustId));
//        Map<String, EntrustmentIdentificationMaterial> materialMap = materialList.stream().collect(Collectors.toMap(EntrustmentIdentificationMaterial::getId, Function.identity()));
        // 获取检测结果
        List<EntrustMaterialCheckoutResultVO> checkoutResultList = baseMapper.voList(Wrappers.<EntrustMaterialCheckoutResult>query().eq("emr.entrust_id", entrustId));
        if (CollUtil.isEmpty(checkoutResultList)) {
            return "";
        }

        List<EntrustMaterialCheckoutResultVO> materialCheckoutResults = checkoutResultList.stream().filter(o -> StrUtil.isNotBlank(o.getQualitativeResult())).collect(Collectors.toList());
        List<EntrustMaterialCheckoutResultVO> materialNotCheckoutResults = checkoutResultList.stream().filter(o -> StrUtil.isBlank(o.getQualitativeResult())).collect(Collectors.toList());

        List<String> resultStrList = new ArrayList<>();
        // 对检测结果进行分组
        Map<String, List<EntrustMaterialCheckoutResultVO>> checkoutResultGroupMap = materialCheckoutResults.stream().collect(Collectors.groupingBy(item -> DrugLiteConvert.joiningDrugListNameToStr(DrugLiteConvert.getDrugLites(item.getQualitativeResult()), "、")));

        checkoutResultGroupMap.forEach((key, value) -> {
            StringBuilder builder = new StringBuilder();
            builder
                    .append(value.stream().map(item -> item.getOrderNo() + "号检材").sorted().collect(Collectors.joining("、")))
                    .append(" : [")
                    .append(key)
                    .append("]");
            resultStrList.add(builder.toString());
        });
        List<String> sortedResult = resultStrList.stream().sorted().collect(Collectors.toList());
        if (CollUtil.isNotEmpty(materialNotCheckoutResults)) {
            String notCheckoutStr = materialNotCheckoutResults.stream().map(result -> result.getOrderNo() + "号检材").sorted().collect(Collectors.joining("、")) + materialNotCheckoutResults.get(0).getCheckoutRemark();
            sortedResult.add(notCheckoutStr);
        }
        return sortedResult.stream().collect(Collectors.joining("\n"));
    }

    /**
     * 根据DTO保存检材得检出结果信息
     *
     * @param dto 检出DTO
     * @return
     */
    @Override
    public boolean save(EntrustMaterialCheckoutResultDTO dto) {
        Entrustment entrustment = entrustmentService.getById(dto.getEntrustId());
        if (entrustment == null) {
            throw new CheckedException("委托信息不存在！");
        }
        if (!entrustment.getStatus().equals(EntrustStatusConstants.ENTRUST_STATUS_ACCEPTED.getStatus())) {
            throw new CheckedException("该委托信息并未被机构受理！");
        }
        List<String> ids = dto.getIds();
        List<EntrustmentIdentificationMaterial> materialList = entrustmentIdentificationMaterialService.list(Wrappers.<EntrustmentIdentificationMaterial>lambdaQuery().in(EntrustmentIdentificationMaterial::getId, ids));
        Map<String, EntrustmentIdentificationMaterial> identificationMaterialMap = materialList.stream().collect(Collectors.toMap(EntrustmentIdentificationMaterial::getId, Function.identity()));
        boolean success = false;
        for (String id : ids) {
            EntrustmentIdentificationMaterial identificationMaterial = identificationMaterialMap.get(id);
            if (identificationMaterial == null) {
                throw new CheckedException(String.format("id为 [%s] 得检材信息不存在！", id));
            }
            EntrustMaterialCheckoutResult entrustMaterialCheckoutResult = EntrustMaterialCheckoutResultConvert.dtoToEntity(dto);
            entrustMaterialCheckoutResult.setId(id);
            entrustMaterialCheckoutResult.setEntrustId(identificationMaterial.getEntrustmentId());
            if (super.count(Wrappers.<EntrustMaterialCheckoutResult>lambdaQuery().eq(EntrustMaterialCheckoutResult::getId, id)) <= 0) {
//            throw new CheckedException(String.format("检材编号 [%s] 的检材检出结果已经存在！", identificationMaterial.getImNo()));
                success = super.save(entrustMaterialCheckoutResult);
            } else {
                success = super.updateById(entrustMaterialCheckoutResult);
            }
        }
        return success;
    }

    /**
     * 根据委托id导出检出结果excel文件
     *
     * @param entrustIds 委托id列表，包含需要导出的委托的id
     * @param response   HttpServletResponse对象，用于将生成的excel文件写入响应中
     */
    @Override
    public void exportExcel(List<String> entrustIds, HttpServletResponse response) throws IOException {
        // 获取委托信息
        List<Entrustment> entrustmentList = entrustmentService.list(
                Wrappers.<Entrustment>lambdaQuery().in(Entrustment::getId, entrustIds)
        );
        // 获取检材信息， 排序的原因是需要数据是有序的
        List<EntrustmentIdentificationMaterial> materialList = entrustmentIdentificationMaterialService.list(
                Wrappers.<EntrustmentIdentificationMaterial>lambdaQuery()
                        .in(EntrustmentIdentificationMaterial::getEntrustmentId, entrustIds)
                        .orderByAsc(EntrustmentIdentificationMaterial::getEntrustmentId)
                        .orderByAsc(EntrustmentIdentificationMaterial::getOrderNo)
        );
        // 获取检材id,后续根据检材id获取对应的检出结果
        List<String> materialIds = materialList.stream().map(EntrustmentIdentificationMaterial::getId).collect(Collectors.toList());
        // 根据委托id进行分组，防止导出的excel数据被打乱
        Map<String, List<EntrustmentIdentificationMaterial>> materialGroupByEntrustMap = materialList.stream().collect(Collectors.groupingBy(EntrustmentIdentificationMaterial::getEntrustmentId));

        // 获取检出结果
        List<EntrustMaterialCheckoutResult> checkoutResultList = super.list(Wrappers.<EntrustMaterialCheckoutResult>lambdaQuery().in(EntrustMaterialCheckoutResult::getId, materialIds));
        Map<String, EntrustMaterialCheckoutResult> checkoutResultMap = checkoutResultList.stream().collect(Collectors.toMap(EntrustMaterialCheckoutResult::getId, Function.identity()));
        List<CheckoutResultExcelDTO> checkoutResultExcelDTOS = fetchCheckoutResultExcelDTOList(entrustmentList, materialGroupByEntrustMap, checkoutResultMap);

        response.setContentType("application/vnd.openxmlformats-officedocument.spreadsheetml.sheet");
        response.setCharacterEncoding("utf-8");
        String fileName = URLEncoder.encode("检材检出结果excel表", "UTF-8").replaceAll("\\+", "%20");
        response.setHeader("Content-disposition", "attachment;filename*=utf-8''" + fileName + ".xlsx");

        // 不使用默认样式
        // 空的头部样式
//        WriteCellStyle headWriteCellStyle = new WriteCellStyle();
//        headWriteCellStyle.setFillForegroundColor(IndexedColors.WHITE.getIndex());
//
//        // 空的内容样式
//        WriteCellStyle contentWriteCellStyle = new WriteCellStyle();
//
//        // 不使用任何样式
//        HorizontalCellStyleStrategy horizontalCellStyleStrategy =
//                new HorizontalCellStyleStrategy(headWriteCellStyle, contentWriteCellStyle);
//
//        FastExcel.write(response.getOutputStream(), CheckoutResultExcelDTO.class)
//                .sheet(LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyy-MM-dd")))
//                .registerWriteHandler(horizontalCellStyleStrategy)
//                .doWrite(checkoutResultExcelDTOS);
        // 使用poi导出
        buildExcel(response, checkoutResultExcelDTOS);
    }

    /**
     * vo 分页对象
     *
     * @param query
     * @return
     */
    @Override
    public IPage<EntrustMaterialCheckoutResultVO> voiPage(EntrustMaterialCheckoutResultQuery query) {
//        IPage<EntrustMaterialCheckoutResult> page = this.page(
//                new Page<>(query.getCurrent(), query.getSize()),
//                Wrappers.<EntrustMaterialCheckoutResult>lambdaQuery()
//                        .eq(StrUtil.isNotBlank(query.getEntrustId()), EntrustMaterialCheckoutResult::getEntrustId, query.getEntrustId())
//                        .orderByDesc(EntrustMaterialCheckoutResult::getUpdateTime)
//        );
//        IPage<EntrustMaterialCheckoutResultVO> voPage = new Page<>();
//        BeanUtils.copyProperties(page, voPage, "records");
//        List<EntrustMaterialCheckoutResult> records = page.getRecords();
//        if (CollUtil.isNotEmpty(records)) {
//            List<EntrustmentIdentificationMaterial> entrustmentIdentificationMaterials = entrustmentIdentificationMaterialService.list(Wrappers.<EntrustmentIdentificationMaterial>lambdaQuery().in(EntrustmentIdentificationMaterial::getId, records.stream().map(EntrustMaterialCheckoutResult::getId).collect(Collectors.toSet())));
//            Map<String, EntrustmentIdentificationMaterial> materialMap = entrustmentIdentificationMaterials.stream().collect(Collectors.toMap(EntrustmentIdentificationMaterial::getId, Function.identity()));
//            List<EntrustMaterialCheckoutResultVO> entrustMaterialCheckoutResultVOS = records.stream().map(record -> {
//                EntrustMaterialCheckoutResultVO entrustMaterialCheckoutResultVO = EntrustMaterialCheckoutResultConvert.entityToVO(record);
//                entrustMaterialCheckoutResultVO.setName(materialMap.get(record.getId()).getName());
//                return entrustMaterialCheckoutResultVO;
//            }).collect(Collectors.toList());
//            voPage.setRecords(entrustMaterialCheckoutResultVOS);
//        }
        return baseMapper.getEntrustMaterialCheckoutResultVOPage(
                new Page<>(query.getCurrent(), query.getSize()),
                Wrappers.<EntrustMaterialCheckoutResultVO>query()
                        .eq(StrUtil.isNotBlank(query.getEntrustId()), "emr.entrust_id", query.getEntrustId())
                        .orderByAsc("em.order_no")
        );
    }

    /**
     * 构建并输出Excel文件。
     *
     * @param response                HttpServletResponse对象，用于输出Excel文件
     * @param checkoutResultExcelDTOS 需要写入Excel的数据列表
     * @throws IOException 如果在写入Excel文件时发生IO异常
     *                     <p>
     *                     此方法用于将给定的checkoutResultExcelDTOS列表数据写入Excel文件，并输出到HttpServletResponse对象中。
     *                     方法首先创建一个新的XSSFWorkbook对象作为Excel工作簿，并为其创建一个名为当前日期时间的工作表。
     *                     接着，根据buildExcelHead方法返回的表头信息构建Excel的表头行。
     *                     然后，遍历checkoutResultExcelDTOS列表，将每个元素的数据写入Excel的对应行中。
     *                     最后，使用response.getOutputStream()获取输出流，将构建好的Excel工作簿写入该输出流中，实现文件的下载。
     */
    private void buildExcel(HttpServletResponse response, List<CheckoutResultExcelDTO> checkoutResultExcelDTOS) throws IOException {
        Workbook workbook = new XSSFWorkbook();
        Sheet sheet = workbook.createSheet(LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyy-MM-dd")));
        // 表头导入
        List<String> head = buildExcelHead();
        // 算上表头的行数
        int rowCount = checkoutResultExcelDTOS.size() + 1;
        for (int i = 0; i < rowCount; i++) {
            if (i == 0) {
                Row row = sheet.createRow(i);
                for (int j = 0; j < head.size(); j++) {
                    row.createCell(j).setCellValue(head.get(j));
                }
            } else {
                // 开始写入具体数据内容
                Row row = sheet.createRow(i);
                CheckoutResultExcelDTO excelDTO = checkoutResultExcelDTOS.get(i - 1);
                row.createCell(0).setCellValue(excelDTO.getOrder());
                row.createCell(1).setCellValue(excelDTO.getDeliverTime());
                row.createCell(2).setCellValue(excelDTO.getClientOrgName());
                row.createCell(3).setCellValue(excelDTO.getProvinceCollectPlace());
                row.createCell(4).setCellValue(excelDTO.getCityCollectPlace());
                row.createCell(5).setCellValue(excelDTO.getAcceptNo());
                row.createCell(6).setCellValue(excelDTO.getOrderNo());
                row.createCell(7).setCellValue(excelDTO.getTypeName());
                row.createCell(8).setCellValue(excelDTO.getColor());
                row.createCell(9).setCellValue(excelDTO.getFormName());
                row.createCell(10).setCellValue(excelDTO.getQualitativeResult());
                row.createCell(11).setCellValue(excelDTO.getQuantitativeResult());
                row.createCell(12).setCellValue(excelDTO.getOtherResult());
                row.createCell(13).setCellValue(excelDTO.getRemark());
            }
        }
        // 输出到流
        workbook.write(response.getOutputStream());
    }

    private List<String> buildExcelHead() {
        List<String> headList = new ArrayList<>();
        headList.add("序号");
        headList.add("送检日期");
        headList.add("送检单位");
        headList.add("检材采集地");
        headList.add("检材采集地");
        headList.add("受理编号");
        headList.add("检材编号");
        headList.add("检材类型");
        headList.add("检材颜色");

        headList.add("检材形态");
        headList.add("定性结果");
        headList.add("定量结果");
        headList.add("其他鉴定结果");
        headList.add("备注");
        return headList;
    }

    /**
     * 根据委托列表、材料映射和检验结果映射生成导出Excel的DTO列表
     *
     * @param entrustList       委托列表
     * @param materialMap       材料映射，键为委托ID，值为对应的材料列表
     * @param checkoutResultMap 检验结果映射，键为委托ID，值为对应的检验结果
     * @return 导出Excel的DTO列表，但此方法实际返回空列表，因为最后返回的是Collections.emptyList()
     */
    private List<CheckoutResultExcelDTO> fetchCheckoutResultExcelDTOList(List<Entrustment> entrustList, Map<String, List<EntrustmentIdentificationMaterial>> materialMap, Map<String, EntrustMaterialCheckoutResult> checkoutResultMap) {
        List<CheckoutResultExcelDTO> checkoutResultExcelDTOList = new ArrayList<>();
        Integer index = 1;
        for (Entrustment entrust : entrustList) {
            List<EntrustmentIdentificationMaterial> materialList = materialMap.get(entrust.getId());
            List<Area> areas = commonFeignService.remoteGetProvinceCityInfo(entrust.getClientOrgId());
            String provinceCollectPlace = areas.get(0).getName();
            String cityCollectPlace = "";
            if (areas.size() > 1) {
                cityCollectPlace = areas.get(1).getName();
            }
            String typeName = getTypeName(entrust);
            if (CollUtil.isNotEmpty(materialList)) {
                for (EntrustmentIdentificationMaterial material : materialList) {
                    CheckoutResultExcelDTO excelDTO = new CheckoutResultExcelDTO();
                    excelDTO.setOrder(index++);
                    excelDTO.setDeliverTime(entrust.getDeliverTime().format(DateTimeFormatter.ofPattern("yyyy/M/d")));
                    excelDTO.setClientOrgName(entrust.getClientOrgName());
                    excelDTO.setProvinceCollectPlace(provinceCollectPlace);
                    excelDTO.setCityCollectPlace(cityCollectPlace);
                    excelDTO.setAcceptNo(entrust.getAcceptNo());
                    excelDTO.setOrderNo(material.getOrderNo());
                    excelDTO.setTypeName(typeName);
                    excelDTO.setColor(material.getColor());
                    excelDTO.setFormName(material.getFormName());
                    EntrustMaterialCheckoutResult entrustMaterialCheckoutResult = checkoutResultMap.get(material.getId());
                    excelDTO.setQualitativeResult(
                            DrugLiteConvert.getDrugLites(entrustMaterialCheckoutResult.getQualitativeResult())
                                    .stream().map(DrugLite::getName).collect(Collectors.joining("、"))
                    );
                    excelDTO.setQuantitativeResult(entrustMaterialCheckoutResult.getQuantitativeResult());
                    excelDTO.setOtherResult(entrustMaterialCheckoutResult.getOtherResult());
                    excelDTO.setRemark(entrustMaterialCheckoutResult.getCheckoutRemark());
                    checkoutResultExcelDTOList.add(excelDTO);
                }
            }
        }
        return checkoutResultExcelDTOList;
    }

    /**
     * 根据委托类型获取委托检材类型的名称
     *
     * @param entrust 委托对象
     * @return 委托类型的名称
     */
    private String getTypeName(Entrustment entrust) {
        String typeName = "";
        if (entrust.getEntrustmentType().equals(0)) {
            typeName = "缴获物";
        } else if (entrust.getEntrustmentType().equals(1)) {
            typeName = "生物样本";
        } else {
            typeName = "其他";
        }
        return typeName;
    }

    /**
     * 获取指定年份的所有毒品类型列表（去重并排序）
     * <p>
     * 该方法通过查询指定年份内所有非空且不为空的定性结果，提取其中的毒品类型信息，
     * 并返回一个去重且按字典序排序的毒品类型列表。
     *
     * @param year  年份，若为 null 则默认使用当前年份
     * @param orgId
     * @return 包含所有毒品类型的列表，列表中的毒品类型名称已去重并排序
     * @see EntrustMaterialCheckoutResult 委托材料检验结果实体类，包含定性结果字段
     * @see DrugLite 药品轻量级实体类，包含药品名称字段
     * @see DrugLiteConvert 工具类，用于将定性结果转换为毒品轻量级实体列表
     */
    @Override
    public List<String> getResultType(Integer year, String orgId) {
        // 根据年份构建查询起始时间
        LocalDateTime startTime = getStartTime(year);
        List<String> entrustIdList = getEntrustIdListByOrgId(orgId);

        // 查询所有非空且不为空的定性结果，且创建时间大于等于起始时间
        List<EntrustMaterialCheckoutResult> list = this.list(Wrappers.<EntrustMaterialCheckoutResult>lambdaQuery()
                .in(CollUtil.isNotEmpty(entrustIdList), EntrustMaterialCheckoutResult::getEntrustId, entrustIdList)
                .ne(EntrustMaterialCheckoutResult::getQualitativeResult, "") // 排除空字符串
                .isNotNull(EntrustMaterialCheckoutResult::getQualitativeResult) // 排除空值
                .ge(EntrustMaterialCheckoutResult::getCreateTime, startTime)); // 创建时间大于等于起始时间

        // 用于存储去重后的毒品类型列表
        ArrayList<String> typeList = new ArrayList<>();

        // 遍历查询结果
        for (EntrustMaterialCheckoutResult result : list) {
            // 将定性结果转换为轻量级实体列表
            List<DrugLite> drugLites = DrugLiteConvert.getDrugLites(result.getQualitativeResult());

            // 遍历药品轻量级实体列表
            for (DrugLite drugLite : drugLites) {
                // 如果毒品类型未添加到列表中，则添加
                if (!typeList.contains(drugLite.getName())) {
                    typeList.add(drugLite.getName());
                }
            }
        }

        // 对列表进行字典序排序
        Collections.sort(typeList);

        // 返回去重并排序后的毒品类型列表
        return typeList;
    }

    // 获取开始时间
    private LocalDateTime getStartTime(Integer year) {
        LocalDateTime startTime = null;
        if (year != null) {
            // 如果年份不为空，使用指定年份的1月1日 00:00:00
            startTime = LocalDateTime.of(year, 1, 1, 0, 0);
        } else {
            // 如果年份为空，默认使用当前年份的1月1日 00:00:00
            startTime = LocalDateTime.of(LocalDateTime.now().getYear(), 1, 1, 0, 0);
        }
        return startTime;
    }

    // 根据机构id获取委托id
    private List<String> getEntrustIdListByOrgId(String orgId) {
        if (StrUtil.isBlank(orgId)) {
            return Collections.emptyList();
        }
        List<Entrustment> entrustmentList = entrustmentService.list(Wrappers.<Entrustment>lambdaQuery().eq(Entrustment::getClientOrgId, orgId));
        return entrustmentList.stream().map(Entrustment::getId).collect(Collectors.toList());
    }


    @Override
    public DetectionRateVO getDetectionRateByMaterial(Integer year, String orgId) {
        // 获取所有毒品类型列表
        List<String> resultType = this.getResultType(year, orgId);
        // 用于存储毒品名称及其检出占比的映射表
        DetectionRateVO vo = new DetectionRateVO();
        ArrayList<String> nameList = new ArrayList<>();
        ArrayList<String> percentList = new ArrayList<>();
        // 根据年份构建查询起始时间
        LocalDateTime startTime = getStartTime(year);
        List<String> entrustIdList = getEntrustIdListByOrgId(orgId);


        // 查询所有非空且不为空的定性结果，且创建时间大于等于起始时间
        List<EntrustmentIdentificationMaterial> materialList = entrustmentIdentificationMaterialService.list(Wrappers.<EntrustmentIdentificationMaterial>lambdaQuery()
                .in(CollUtil.isNotEmpty(entrustIdList), EntrustmentIdentificationMaterial::getEntrustmentId, entrustIdList)
                .ge(EntrustmentIdentificationMaterial::getAcceptTime, startTime)
                .eq(EntrustmentIdentificationMaterial::getAcceptPassed, 1));


        // 如果查询结果为空，直接返回 null
        if (materialList == null || materialList.size() == 0) {
            return null;
        }

        // 获取分母（总结果数）
        double denominator = materialList.size();

        // 遍历每种毒品类型，计算其检出占比
        for (String drugName : resultType) {
            // 查询包含当前毒品名称的定性结果
            List<EntrustMaterialCheckoutResult> list = this.list(Wrappers.<EntrustMaterialCheckoutResult>lambdaQuery()
                    .like(EntrustMaterialCheckoutResult::getQualitativeResult, drugName));

            // 如果查询结果不为空，计算检出占比并存入映射表
            if (list != null && list.size() > 0) {
                double molecule = list.size(); // 分子
                BigDecimal d1 = new BigDecimal(molecule);
                BigDecimal d2 = new BigDecimal(denominator); // 分母
                // 计算百分比（保留2位小数，四舍五入）
                double percentage = d1.divide(d2, 4, BigDecimal.ROUND_HALF_UP)
                        .multiply(new BigDecimal(100))
                        .doubleValue();
                nameList.add(drugName);
                percentList.add(String.format("%.2f%%", percentage));
            }
        }
        vo.setNameList(nameList);
        vo.setPercentList(percentList);
        // 返回包含毒品名称及其检出占比的映射表
        return vo;
    }

    @Override
    public IPage<EntrustmentIdentificationMaterialVO> getMaterialByDetection(String drugName, Integer year, Page page) {

        List<EntrustMaterialCheckoutResult> list = this.list(Wrappers.<EntrustMaterialCheckoutResult>lambdaQuery()
                .like(EntrustMaterialCheckoutResult::getQualitativeResult, drugName));

        ArrayList<String> materialIdList = new ArrayList<>();

        for (EntrustMaterialCheckoutResult result : list) {
            materialIdList.add(result.getId());
        }

        LocalDateTime startTime = this.getStartTime(year);

        Page materialPage = entrustmentIdentificationMaterialService.page(page, Wrappers.<EntrustmentIdentificationMaterial>lambdaQuery()
                .in(EntrustmentIdentificationMaterial::getId, materialIdList)
                .ge(EntrustmentIdentificationMaterial::getAcceptTime, startTime)
                .orderByDesc(EntrustmentIdentificationMaterial::getAcceptTime));
        return materialPage;
    }

    public List<EntrustmentIdentificationMaterialVO> getResultData(ResultExcelDTO excelDTO) {

        LocalDateTime startTime = excelDTO.getStartTime();
        LocalDateTime endTime = excelDTO.getEndTime();
        List<String> oldResults = excelDTO.getOldResult();
        Integer entrustType = excelDTO.getEntrustType();
        // 创建查询条件包装器
        LambdaQueryWrapper<Entrustment> wrapper = new LambdaQueryWrapper<>();

        // 设置时间范围过滤条件
        if (startTime != null && endTime != null) {
            wrapper.between(Entrustment::getAcceptTime, startTime, endTime);

        } else {
            wrapper.ge(Entrustment::getAcceptTime, this.getStartTime(null));
        }
        List<String> allResults = new ArrayList<>();
        for (String oldResult : oldResults) {
            if (StringUtils.isNotBlank(oldResult)) {
                if ("委托".equals(oldResult)) {
                    allResults.add("首次鉴定");
                    allResults.add("补充鉴定");
                    allResults.add("重新鉴定");
                } else {
                    allResults.add(oldResult);
                }
            }
        }

        if (!allResults.isEmpty()) {
            wrapper.in(Entrustment::getOldIdentificationResult, allResults);
        }

        // 查询符合条件的 Entrustment 列表，避免重复查询数据库
        List<Entrustment> entrustmentList = entrustmentService.list(
                wrapper.eq(entrustType != null, Entrustment::getEntrustmentType, entrustType)
        );

        System.out.println("委托的数量:" + entrustmentList.size());
        // 如果无符合条件的委托信息，则返回空列表
        if (CollUtil.isEmpty(entrustmentList)) {
            return Collections.emptyList();
        }

        // 获取符合条件的委托 ID 集合，提高查询效率
        Set<String> entrustIds = entrustmentList.stream()
                .map(Entrustment::getId)
                .collect(Collectors.toSet());

        // 将 Entrustment 列表转换为 Map，提高后续查询速度
        Map<String, Entrustment> entrustMap = entrustmentList.stream()
                .collect(Collectors.toMap(Entrustment::getId, Function.identity()));

        // 查询所有符合条件的 EntrustmentIdentificationMaterial 数据
        List<EntrustmentIdentificationMaterial> materialList = entrustmentIdentificationMaterialService.list(
                Wrappers.<EntrustmentIdentificationMaterial>lambdaQuery()
                        .in(EntrustmentIdentificationMaterial::getEntrustmentId, entrustIds)
        );

        // 若无符合条件的材料，则直接返回空列表
        if (CollUtil.isEmpty(materialList)) {
            return Collections.emptyList();
        }

        // 获取材料 ID 集合，提高查询效率
        Set<String> materialIds = materialList.stream()
                .map(EntrustmentIdentificationMaterial::getId)
                .collect(Collectors.toSet());

        // 查询所有符合条件的检测结果数据
        List<EntrustMaterialCheckoutResult> resultList = this.list(
                Wrappers.<EntrustMaterialCheckoutResult>lambdaQuery()
                        .in(EntrustMaterialCheckoutResult::getId, materialIds)
        );

        // 将检测结果转换为 Map
        Map<String, EntrustMaterialCheckoutResult> resultMap = resultList.stream()
                .collect(Collectors.toMap(EntrustMaterialCheckoutResult::getId, Function.identity()));

        // 构造返回的 VO 列表
        List<EntrustmentIdentificationMaterialVO> voList = materialList.stream().map(material -> {
            EntrustmentIdentificationMaterialVO vo = new EntrustmentIdentificationMaterialVO();
            BeanUtils.copyProperties(material, vo);

            // 设置检测结果
            vo.setDrugLites(Optional.ofNullable(resultMap.get(material.getId()))
                    .map(EntrustMaterialCheckoutResult::getQualitativeResult)
                    .map(DrugLiteConvert::getDrugLites)
                    .orElse(null));

            // 设置委托信息
            Entrustment entrust = entrustMap.get(material.getEntrustmentId());
            if (entrust != null) {
                String oldIdentificationResult = entrust.getOldIdentificationResult();
                vo.setOldIdentificationResult(
                        ("首次鉴定".equals(oldIdentificationResult) || "补充鉴定".equals(oldIdentificationResult) || "重新鉴定".equals(oldIdentificationResult))
                                ? "委托"
                                : oldIdentificationResult
                );
                vo.setOrgName(entrust.getClientOrgName());
            }
            return vo;
        }).collect(Collectors.toList());

        // 按 acceptNo 进行排序并返回结果
        return entrustmentIdentificationMaterialService.sortVoByAcceptNo(voList);
    }


    public Map<String, List<EntrustmentIdentificationMaterialVO>> getResultDataMap(
            ResultExcelDTO excelDTO) {
        LocalDateTime startTime = excelDTO.getStartTime();
        LocalDateTime endTime = excelDTO.getEndTime();
        List<String> oldResults = excelDTO.getOldResult();
        Integer entrustType = excelDTO.getEntrustType();
        try {
            // 1. 构建查询条件
            LambdaQueryWrapper<Entrustment> qw = new LambdaQueryWrapper<>();

            // 时间过滤条件
            if (startTime != null && endTime != null) {
                qw.ge(Entrustment::getAcceptTime, startTime).le(Entrustment::getCreateTime, endTime);
            } else {
                qw.ge(Entrustment::getAcceptTime, this.getStartTime(null));
            }

            List<String> allResults = new ArrayList<>();
            for (String oldResult : oldResults) {
                if (StringUtils.isNotBlank(oldResult)) {
                    if ("委托".equals(oldResult)) {
                        allResults.add("首次鉴定");
                        allResults.add("补充鉴定");
                        allResults.add("重新鉴定");
                    } else {
                        allResults.add(oldResult);
                    }
                }
            }

            if (!allResults.isEmpty()) {
                qw.in(Entrustment::getOldIdentificationResult, allResults);
            }

            // 2. 查询委托数据
            List<Entrustment> entrusts = entrustmentService.list(qw
                    .eq(Entrustment::getEntrustmentType, entrustType)
                    .ge(Entrustment::getStatus, EntrustStatusConstants.ENTRUST_STATUS_ACCEPTED.getStatus()));

            if (entrusts.isEmpty()) {
                return Collections.emptyMap();
            }

            // 将 Entrustment 转换为 Map，以 ID 为 Key，减少后续查询数据库的次数
            Map<String, Entrustment> entrustMap = entrusts.stream()
                    .collect(Collectors.toMap(Entrustment::getId, Function.identity()));

            Set<String> entrustIdList = entrustMap.keySet();

            // 3. 查询符合条件的检验结果
            List<EntrustMaterialCheckoutResult> newResultList = this.list(Wrappers.<EntrustMaterialCheckoutResult>lambdaQuery()
                    .in(EntrustMaterialCheckoutResult::getEntrustId, entrustIdList)
                    .isNotNull(EntrustMaterialCheckoutResult::getQualitativeResult)
                    .ne(EntrustMaterialCheckoutResult::getQualitativeResult, ""));

            if (newResultList.isEmpty()) {
                return Collections.emptyMap();
            }

            // 4. 提取所有涉及的毒品名称（去重）
            Set<String> drugNames = new HashSet<>();
            for (EntrustMaterialCheckoutResult result : newResultList) {
                List<DrugLite> drugLites = DrugLiteConvert.getDrugLites(result.getQualitativeResult());
                for (DrugLite drugLite : drugLites) {
                    drugNames.add(drugLite.getName());
                }
            }

            // 5. 处理不同毒品名称的数据
            Map<String, List<EntrustmentIdentificationMaterialVO>> resultMap = new HashMap<>();

            for (String drugName : drugNames) {
                // 5.1 查询所有含有该毒品的检验结果
                List<EntrustMaterialCheckoutResult> resultList = this.list(Wrappers.<EntrustMaterialCheckoutResult>lambdaQuery()
                        .like(EntrustMaterialCheckoutResult::getQualitativeResult, drugName)
                        .in(EntrustMaterialCheckoutResult::getEntrustId, entrustIdList));

                if (resultList.isEmpty()) {
                    continue;
                }

                // 转换为 Map，方便后续查找
                Map<String, EntrustMaterialCheckoutResult> checkoutResultMap = resultList.stream()
                        .collect(Collectors.toMap(EntrustMaterialCheckoutResult::getId, Function.identity()));

                // 5.2 获取相关的鉴定材料
                Set<String> materialIdSet = checkoutResultMap.keySet();
                List<EntrustmentIdentificationMaterial> materialList = entrustmentIdentificationMaterialService.list(Wrappers.<EntrustmentIdentificationMaterial>lambdaQuery()
                        .in(EntrustmentIdentificationMaterial::getId, materialIdSet));

                if (materialList.isEmpty()) {
                    continue;
                }

                // 5.3 组装 VO 数据
                List<EntrustmentIdentificationMaterialVO> voList = new ArrayList<>();
                for (EntrustmentIdentificationMaterial material : materialList) {
                    Entrustment entrust = entrustMap.get(material.getEntrustmentId());
                    if (entrust == null) continue;

                    EntrustmentIdentificationMaterialVO vo = new EntrustmentIdentificationMaterialVO();
                    BeanUtils.copyProperties(material, vo);
                    vo.setOrgName(entrust.getClientOrgName());
                    String oldIdentificationResult = entrust.getOldIdentificationResult();
                    if (oldIdentificationResult.equals("首次鉴定") || oldIdentificationResult.equals("补充鉴定") || oldIdentificationResult.equals("重新鉴定")) {
                        vo.setOldIdentificationResult("委托");
                    } else {
                        vo.setOldIdentificationResult(oldIdentificationResult);
                    }
                    EntrustMaterialCheckoutResult checkoutResult = checkoutResultMap.get(vo.getId());
                    if (checkoutResult != null) {
                        vo.setDrugLites(DrugLiteConvert.getDrugLites(checkoutResult.getQualitativeResult()));
                    }

                    voList.add(vo);
                }

                // 5.4 按受理编号排序
                voList.sort(Comparator.comparing(EntrustmentIdentificationMaterialVO::getAcceptNo, (a, b) -> {
                    try {
                        String[] partsA = a.split("-");
                        String[] partsB = b.split("-");
                        if (partsA.length != 3 || partsB.length != 3) return 0;

                        int yearA = Integer.parseInt(partsA[0]), serialA = Integer.parseInt(partsA[1]), subSerialA = Integer.parseInt(partsA[2]);
                        int yearB = Integer.parseInt(partsB[0]), serialB = Integer.parseInt(partsB[1]), subSerialB = Integer.parseInt(partsB[2]);

                        return Comparator.comparingInt((int[] arr) -> arr[0])
                                .thenComparingInt(arr -> arr[1])
                                .thenComparingInt(arr -> arr[2])
                                .compare(new int[]{yearA, serialA, subSerialA}, new int[]{yearB, serialB, subSerialB});
                    } catch (Exception e) {
                        return 0; // 防止解析错误导致异常
                    }
                }));

                resultMap.put(drugName, voList);
            }

            return resultMap;

        } catch (Exception e) {
            log.error("获取结果数据失败: ", e);
            return Collections.emptyMap();
        }
    }

    @Override
    public R getExcelByResult(HttpServletResponse response, ResultExcelDTO excelDTO) throws IOException {
        // 获取查询数据
        List<EntrustmentIdentificationMaterialVO> resultData = this.getResultData(excelDTO);
        Map<String, List<EntrustmentIdentificationMaterialVO>> resultDataMap = this.getResultDataMap(excelDTO);

        LocalDateTime startTime = excelDTO.getStartTime();
        LocalDateTime endTime = excelDTO.getEndTime();
        Integer entrustType = excelDTO.getEntrustType();
        List<String> oldResults = excelDTO.getOldResult();

        if (resultData.isEmpty() || resultDataMap.isEmpty()) {
            return R.failed("没有符合条件的数据!");
        }

        Workbook workbook = new XSSFWorkbook();

        createDataSheet(workbook, entrustType, resultData);
        createStatisticsSheet(workbook, resultDataMap, oldResults, entrustType, startTime, endTime);
        createDrugSheets(workbook, resultDataMap, entrustType);

        workbook.write(response.getOutputStream());
        return R.ok("导出成功!");
    }

    private void createDataSheet(Workbook workbook, Integer entrustType, List<EntrustmentIdentificationMaterialVO> resultData) {
        // 确定表名
        String sheetName = (entrustType == 0) ? "常规毒品" : "生物样本";
        Sheet sheet = workbook.createSheet(sheetName);

        // 定义表头
        String[] inVivoHeaders = {"检材类型", "检材编号", "检材名称", "检材性状", "检材质量", "年龄", "性别", "委托单位", "受理日期", "检出结果"};
        String[] inVitroHeaders = {"检材类型", "检材编号", "检材名称", "检材性状", "检材质量", "委托单位", "受理日期", "检出结果"};
        String[] headers = (entrustType == 0) ? inVitroHeaders : inVivoHeaders;

        // 创建表头行
        Row headerRow = sheet.createRow(0);
        for (int i = 0; i < headers.length; i++) {
            headerRow.createCell(i).setCellValue(headers[i]);
            sheet.setColumnWidth(i, 20 * 256);
        }
        int masculineSize = 0;
        // 填充数据
        for (int i = 0; i < resultData.size(); i++) {
            EntrustmentIdentificationMaterialVO vo = resultData.get(i);
            Row row = sheet.createRow(i + 1);
            fillRowData(row, vo, entrustType);
            if (CollUtil.isNotEmpty(vo.getDrugLites())) {
                masculineSize++;
            }
        }
        Row lastRow = sheet.createRow(resultData.size() + 2);
        lastRow.createCell(0).setCellValue("检材总数量:" + resultData.size());
        lastRow.createCell(1).setCellValue("阳性总数量:" + masculineSize);
        BigDecimal result = new BigDecimal(masculineSize)
                .multiply(new BigDecimal(100))
                .divide(new BigDecimal(resultData.size()), 2, RoundingMode.HALF_UP);
        lastRow.createCell(2).setCellValue("总检出率:" + result.toString() + "%");
    }

    private void createStatisticsSheet(Workbook workbook, Map<String, List<EntrustmentIdentificationMaterialVO>> resultDataMap, List<String> oldResults, Integer entrustType, LocalDateTime startTime, LocalDateTime endTime) {
        Sheet sheet = workbook.createSheet("统计");

        String[] headers = {"化合物种类", "检出数量", "总数量", "检出率"};

        // 创建表头
        Row headerRow = sheet.createRow(0);
        for (int i = 0; i < headers.length; i++) {
            headerRow.createCell(i).setCellValue(headers[i]);
            sheet.setColumnWidth(i, 20 * 256);
        }

        // 获取总数量
        Integer size = this.getSizeMap(entrustType, oldResults, startTime, endTime);

        // 填充统计数据
        int rowIndex = 1;
        for (Map.Entry<String, List<EntrustmentIdentificationMaterialVO>> entry : resultDataMap.entrySet()) {
            String drugName = entry.getKey();
            List<EntrustmentIdentificationMaterialVO> materials = entry.getValue();
            Row row = sheet.createRow(rowIndex++);
            row.createCell(0).setCellValue(drugName);
            row.createCell(1).setCellValue(materials.size());
            row.createCell(2).setCellValue(size);
            row.createCell(3).setCellValue(String.format("%.2f%%", materials.size() * 100.0 / size));
        }
    }

    private void createDrugSheets(Workbook workbook, Map<String, List<EntrustmentIdentificationMaterialVO>> resultDataMap, Integer entrustType) {
        for (Map.Entry<String, List<EntrustmentIdentificationMaterialVO>> entry : resultDataMap.entrySet()) {
            String drugName = entry.getKey().replaceAll("[^\u4e00-\u9fa5a-zA-Z0-9]", "");
            Sheet sheet = workbook.createSheet(drugName);

            // 定义表头
            String[] headers = (entrustType == 0) ? new String[]{"检材类型", "检材编号", "检材名称", "检材性状", "检材质量", "委托单位", "受理日期", "检出结果"}
                    : new String[]{"检材类型", "检材编号", "检材名称", "检材性状", "检材质量", "年龄", "性别", "委托单位", "受理日期", "检出结果"};

            // 创建表头行
            Row headerRow = sheet.createRow(0);
            for (int i = 0; i < headers.length; i++) {
                headerRow.createCell(i).setCellValue(headers[i]);
                sheet.setColumnWidth(i, 20 * 256);
            }

            // 填充数据
            int rowIndex = 1;
            for (EntrustmentIdentificationMaterialVO vo : entry.getValue()) {
                Row row = sheet.createRow(rowIndex++);
                fillRowData(row, vo, entrustType);
            }
        }
    }

    private void fillRowData(Row row, EntrustmentIdentificationMaterialVO vo, Integer entrustType) {
        row.createCell(0).setCellValue(vo.getOldIdentificationResult());
        row.createCell(1).setCellValue(vo.getAcceptNo());
        row.createCell(2).setCellValue(vo.getName());
        row.createCell(3).setCellValue(vo.getFormName());
        row.createCell(4).setCellValue(vo.getQuantity() + vo.getUnit());

        if (entrustType == 1) {
            row.createCell(5).setCellValue(vo.getMaterialAge() != null || vo.getMaterialAge() != 0 ? vo.getMaterialAge().toString() + "岁" : "未知");
            row.createCell(6).setCellValue(StringUtils.isNotBlank(vo.getBiologyGender()) ? vo.getBiologyGender() : "未知");
            row.createCell(7).setCellValue(vo.getOrgName());
            row.createCell(8).setCellValue(LocalDateTimeUtil.format(vo.getAcceptTime(), "yyyy-MM-dd"));
            List<DrugLite> drugLites = vo.getDrugLites();
            if (drugLites != null && !drugLites.isEmpty()) {
                String result = drugLites.stream()
                        .map(DrugLite::getName)
                        .collect(Collectors.joining(","));  // 自动去除最后的逗号
                row.createCell(9).setCellValue(result);
            } else {
                row.createCell(9).setCellValue("未检出");
            }
        } else {
            row.createCell(5).setCellValue(vo.getOrgName());
            row.createCell(6).setCellValue(LocalDateTimeUtil.format(vo.getAcceptTime(), "yyyy-MM-dd"));
            List<DrugLite> drugLites = vo.getDrugLites();
            if (drugLites != null && !drugLites.isEmpty()) {
                String result = drugLites.stream()
                        .map(DrugLite::getName)
                        .collect(Collectors.joining(","));  // 自动去除最后的逗号
                row.createCell(7).setCellValue(result);
            } else {
                row.createCell(7).setCellValue("未检出");
            }
        }
    }


    public Integer getSizeMap(Integer entrustType, List<String> oldResults, LocalDateTime startTime, LocalDateTime endTime) {
        // 构造查询条件，查询 EntrustmentIdentificationMaterial 数据

        LocalDateTime queryStartTime = Optional.ofNullable(startTime).orElseGet(() -> this.getStartTime(null));


        // 统计各类委托的数量
        int entrustSize = 0;
        int preliminaryScreeningSize = 0;
        int myanmarRelatedSize = 0;
        int voluntaryRehabilitationSize = 0;

        // 构造查询条件，查询 Entrustment 数据
        LambdaQueryWrapper<Entrustment> wrapper = new LambdaQueryWrapper<>();
        if (endTime != null) {
            wrapper.between(Entrustment::getAcceptTime, queryStartTime, endTime);
        } else {
            wrapper.ge(Entrustment::getAcceptTime, queryStartTime);
        }

        ArrayList<String> results = new ArrayList<>();
        for (String oldResult : oldResults) {
            if (oldResult.equals("委托")) {
                results.add("首次鉴定");
                results.add("补充鉴定");
                results.add("重新鉴定");
            } else results.add(oldResult);
        }

        // 查询符合条件的 Entrustment 记录
        List<Entrustment> entrusts = entrustmentService.list(wrapper
                .eq(Entrustment::getEntrustmentType, entrustType)
                .ge(Entrustment::getStatus, EntrustStatusConstants.ENTRUST_STATUS_ACCEPTED.getStatus())
                .in(Entrustment::getOldIdentificationResult, results)
        );

        List<String> entrustIds = entrusts.stream().map(Entrustment::getId).collect(Collectors.toList());

        return entrustmentIdentificationMaterialService.lambdaQuery()
                .in(EntrustmentIdentificationMaterial::getEntrustmentId, entrustIds)
                .list()
                .size();
//
//        // 按照 oldIdentificationResult 进行分组
//        Map<String, List<Entrustment>> entrustMap = entrusts.stream()
//                .collect(Collectors.groupingBy(Entrustment::getOldIdentificationResult));
//
//        // 遍历分组数据，计算各类 EntrustmentIdentificationMaterial 的数量
//        for (Map.Entry<String, List<Entrustment>> entry : entrustMap.entrySet()) {
//            String oldIdentificationResult = entry.getKey();
//            List<Entrustment> entrustList = entry.getValue();
//
//            // 获取 Entrustment ID 列表
//            List<String> entIdList = entrustList.stream()
//                    .map(Entrustment::getId)
//                    .collect(Collectors.toList());
//
//            // 查询与这些 Entrustment 关联的 EntrustmentIdentificationMaterial 数量
//            int size = entrustmentIdentificationMaterialService.list(Wrappers.<EntrustmentIdentificationMaterial>lambdaQuery()
//                    .in(EntrustmentIdentificationMaterial::getEntrustmentId, entIdList)).size();
//
//            // 根据 oldIdentificationResult 分类累加数量
//            switch (oldIdentificationResult) {
//                case "初筛":
//                    preliminaryScreeningSize += size;
//                    break;
//                case "涉缅人员":
//                    myanmarRelatedSize += size;
//                    break;
//                case "自愿戒治人员":
//                    voluntaryRehabilitationSize += size;
//                    break;
//                default:
//                    entrustSize += size;
//                    break;
//            }
//        }
//
//        // 组装返回结果
//        Map<String, Integer> sizeMap = new HashMap<>();
//        sizeMap.put("委托", entrustSize);
//        sizeMap.put("初筛", preliminaryScreeningSize);
//        sizeMap.put("涉缅人员", myanmarRelatedSize);
//        sizeMap.put("自愿戒治人员", voluntaryRehabilitationSize);

//        return entrusts.size();
    }

}




